@@ -1,7 +1,7 @@
 package Complete::Util;
 
-our $DATE = '2015-06-08'; # DATE
-our $VERSION = '0.31'; # VERSION
+our $DATE = '2015-08-11'; # DATE
+our $VERSION = '0.32'; # VERSION
 
 use 5.010001;
 use strict;
@@ -123,8 +123,6 @@ _
     },
 };
 sub complete_array_elem {
-    use experimental 'smartmatch';
-
     my %args  = @_;
     my $array = $args{array} or die "Please specify array";
     my $word  = $args{word} // "";
@@ -140,13 +138,13 @@ sub complete_array_elem {
 
     my $wordu = uc($word);
     my @words;
-    for (@$array) {
-        my $uc = uc($_) if $ci;
-        next unless 0==($ci ? index($uc, $wordu) : index($_, $word));
+    for my $el (@$array) {
+        my $uc = uc($el) if $ci;
+        next unless 0==($ci ? index($uc, $wordu) : index($el, $word));
         if ($has_exclude) {
-            next if ($ci ? $uc : $_) ~~ @$exclude;
+            next if grep {($ci ? $uc : $el) eq $_} @$exclude;
         }
-        push @words, $_;
+        push @words, $el;
     }
     $ci ? [sort {lc($a) cmp lc($b)} @words] : [sort @words];
 }
@@ -553,7 +551,7 @@ Complete::Util - General completion routine
 
 =head1 VERSION
 
-This document describes version 0.31 of Complete::Util (from Perl distribution Complete-Util), released on 2015-06-08.
+This document describes version 0.32 of Complete::Util (from Perl distribution Complete-Util), released on 2015-08-11.
 
 =head1 DESCRIPTION
 
@@ -562,10 +560,12 @@ This document describes version 0.31 of Complete::Util (from Perl distribution C
 
 =head2 arrayify_answer(%args) -> array
 
-Make sure we return completion answer in array form.
+{en_US Make sure we return completion answer in array form}.
 
+{en_US 
 This is the reverse of C<hashify_answer>. It accepts a hash or an array. If it
 receives a hash, will return its C<words> key.
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -573,6 +573,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<arg>* => I<array|hash>
 
+{en_US }.
+
 =back
 
 Return value:  (array)
@@ -580,8 +582,9 @@ Return value:  (array)
 
 =head2 combine_answers($answers, ...) -> hash
 
-Given two or more answers, combine them into one.
+{en_US Given two or more answers, combine them into one}.
 
+{en_US 
 This function is useful if you want to provide a completion answer that is
 gathered from multiple sources. For example, say you are providing completion
 for the Perl tool C<cpanm>, which accepts a filename (a tarball like C<*.tar.gz>),
@@ -594,6 +597,7 @@ a directory, or a module name. You can do something like this:
 
 If a completion answer has a metadata C<final> set to true, then that answer is
 used as the final answer without any combining with the other answers.
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -606,16 +610,20 @@ Arguments ('*' denotes required arguments):
 Return value:  (hash)
 
 
+{en_US 
 Return a combined completion answer. Words from each input answer will be
 combined, order preserved and duplicates removed. The other keys from each
 answer will be merged.
+}
 
 
 =head2 complete_array_elem(%args) -> array
 
-Complete from array.
+{en_US Complete from array}.
 
+{en_US 
 Will sort the resulting completion list, so you don't have to presort the array.
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -636,10 +644,12 @@ Return value:  (array)
 
 =head2 complete_env(%args) -> array
 
-Complete from environment variables.
+{en_US Complete from environment variables}.
 
+{en_US 
 On Windows, environment variable names are all converted to uppercase. You can
 use case-insensitive option (C<ci>) to match against original casing.
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -656,7 +666,7 @@ Return value:  (array)
 
 =head2 complete_file(%args) -> array
 
-Complete file and directory from local filesystem.
+{en_US Complete file and directory from local filesystem}.
 
 Arguments ('*' denotes required arguments):
 
@@ -664,14 +674,16 @@ Arguments ('*' denotes required arguments):
 
 =item * B<allow_dot> => I<bool> (default: 1)
 
-If turned off, will not allow "." or ".." in path.
+{en_US If turned off, will not allow "." or ".." in path}.
 
+{en_US 
 This is most useful when combined with C<starting_path> option to prevent user
 going up/outside the starting path.
+}
 
 =item * B<ci> => I<bool>
 
-Case-insensitive matching.
+{en_US Case-insensitive matching}.
 
 =item * B<dig_leaf> => I<bool>
 
@@ -679,16 +691,19 @@ Case-insensitive matching.
 
 =item * B<file_regex_filter> => I<re>
 
-Filter shortcut for file regex.
+{en_US Filter shortcut for file regex}.
 
+{en_US 
 This is a shortcut for constructing a filter. So instead of using C<filter>, you
 use this option. This will construct a filter of including only directories or
 regular files, and the file must match a regex pattern. This use-case is common.
+}
 
 =item * B<filter> => I<str|code>
 
-Only return items matching this filter.
+{en_US Only return items matching this filter}.
 
+{en_US 
 Filter can either be a string or a code.
 
 For string filter, you can specify a pipe-separated groups of sequences of these
@@ -701,6 +716,7 @@ files or writable directories.
 For code filter, you supply a coderef. The coderef will be called for each item
 with these arguments: C<$name>. It should return true if it wants the item to be
 included.
+}
 
 =item * B<handle_tilde> => I<bool> (default: 1)
 
@@ -717,7 +733,7 @@ Return value:  (array)
 
 =head2 complete_hash_key(%args) -> array
 
-Complete from hash keys.
+{en_US Complete from hash keys}.
 
 Arguments ('*' denotes required arguments):
 
@@ -736,9 +752,11 @@ Return value:  (array)
 
 =head2 complete_program(%args) -> array
 
-Complete program name found in PATH.
+{en_US Complete program name found in PATH}.
 
+{en_US 
 Windows is supported, on Windows PATH will be split using /;/ instead of /:/.
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -755,13 +773,15 @@ Return value:  (array)
 
 =head2 hashify_answer(%args) -> hash
 
-Make sure we return completion answer in hash form.
+{en_US Make sure we return completion answer in hash form}.
 
+{en_US 
 This function accepts a hash or an array. If it receives an array, will convert
 the array into `{words=>$ary}' first to make sure the completion answer is in
 hash form.
 
 Then will add keys from C<meta> to the hash.
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -769,9 +789,11 @@ Arguments ('*' denotes required arguments):
 
 =item * B<arg>* => I<array|hash>
 
+{en_US }.
+
 =item * B<meta> => I<hash>
 
-Metadata (extra keys) for the hash.
+{en_US Metadata (extra keys) for the hash}.
 
 =back
 
